@@ -8,7 +8,7 @@
 
 #include "failpage.h"
 #include "../sendfilewizard.h"
-#include "debug_p.h"
+#include "bluedevil_sendfile.h"
 
 #include <QPushButton>
 
@@ -29,19 +29,17 @@ FailPage::FailPage(SendFileWizard *parent)
 
 void FailPage::initializePage()
 {
-    qCDebug(SENDFILE) << "Initialize Fail Page";
+    qCDebug(BLUEDEVIL_SENDFILE_LOG) << "Initialize Fail Page";
 
-    QList<QWizard::WizardButton> list;
-    list << QWizard::Stretch;
-    list << QWizard::CancelButton;
+    const QList<QWizard::WizardButton> list{QWizard::Stretch, QWizard::CancelButton};
 
     m_wizard->setButtonLayout(list);
 
     BluezQt::DevicePtr device = m_wizard->device();
 
     if (device->name().isEmpty()) {
-        failLbl->setText(i18nc("This string is shown when the wizard fail", "The connection to the device has failed"));
+        failLbl->setText(i18nc("This string is shown when the wizard fail", "The connection to the device has failed: %1", m_wizard->errorMessage()));
     } else {
-        failLbl->setText(i18n("The connection to %1 has failed", device->name()));
+        failLbl->setText(i18n("The connection to %1 has failed: %2", device->name(), m_wizard->errorMessage()));
     }
 }
