@@ -8,7 +8,7 @@
 #include "discover.h"
 #include "../bluewizard.h"
 #include "../wizardagent.h"
-#include "debug_p.h"
+#include "bluedevil_wizard.h"
 
 #include <QAction>
 #include <QRegularExpressionValidator>
@@ -37,12 +37,11 @@ public:
     BluezQt::DevicePtr device(const QModelIndex &index) const;
 
 private:
-    BluezQt::DevicesModel *m_devicesModel;
+    BluezQt::DevicesModel *m_devicesModel = nullptr;
 };
 
 DevicesProxyModel::DevicesProxyModel(QObject *parent)
     : QSortFilterProxyModel(parent)
-    , m_devicesModel(nullptr)
 {
     setDynamicSortFilter(true);
     sort(0, Qt::DescendingOrder);
@@ -96,14 +95,11 @@ BluezQt::DevicePtr DevicesProxyModel::device(const QModelIndex &index) const
 DiscoverPage::DiscoverPage(BlueWizard *parent)
     : QWizardPage(parent)
     , m_wizard(parent)
-    , m_model(nullptr)
-    , m_manager(nullptr)
-    , m_warningWidget(nullptr)
+    , m_model(new DevicesProxyModel(this))
 {
     setupUi(this);
     setTitle(i18n("Select a device"));
 
-    m_model = new DevicesProxyModel(this);
     deviceView->setModel(m_model);
 
     connect(deviceView->selectionModel(), &QItemSelectionModel::currentChanged, this, &DiscoverPage::indexSelected);
@@ -112,7 +108,7 @@ DiscoverPage::DiscoverPage(BlueWizard *parent)
 
 void DiscoverPage::initializePage()
 {
-    qCDebug(WIZARD) << "Initialize Discover Page";
+    qCDebug(BLUEDEVIL_WIZARD_LOG) << "Initialize Discover Page";
 
     QList<QWizard::WizardButton> list;
     list << QWizard::Stretch;
@@ -131,7 +127,7 @@ void DiscoverPage::initializePage()
 
     m_adapter = m_manager->usableAdapter();
     if (m_adapter && !m_adapter->isDiscovering()) {
-        qCDebug(WIZARD) << "Starting scanning";
+        qCDebug(BLUEDEVIL_WIZARD_LOG) << "Starting scanning";
         m_adapter->startDiscovery();
     }
 
@@ -186,7 +182,7 @@ int DiscoverPage::nextId() const
     }
 
     if (m_adapter && m_adapter->isDiscovering()) {
-        qCDebug(WIZARD) << "Stopping scanning";
+        qCDebug(BLUEDEVIL_WIZARD_LOG) << "Stopping scanning";
         m_adapter->stopDiscovery();
     }
 
@@ -197,10 +193,10 @@ int DiscoverPage::nextId() const
         m_wizard->agent()->setPin(pin);
     }
 
-    qCDebug(WIZARD) << "Device type: " << BluezQt::Device::typeToString(device->type());
-    qCDebug(WIZARD) << "Legacy: " << device->hasLegacyPairing();
-    qCDebug(WIZARD) << "From DB: " << m_wizard->agent()->isFromDatabase();
-    qCDebug(WIZARD) << "PIN: " << pin;
+    qCDebug(BLUEDEVIL_WIZARD_LOG) << "Device type: " << BluezQt::Device::typeToString(device->type());
+    qCDebug(BLUEDEVIL_WIZARD_LOG) << "Legacy: " << device->hasLegacyPairing();
+    qCDebug(BLUEDEVIL_WIZARD_LOG) << "From DB: " << m_wizard->agent()->isFromDatabase();
+    qCDebug(BLUEDEVIL_WIZARD_LOG) << "PIN: " << pin;
 
     // NULL pin means that we should only connect to device
     if (pin == QLatin1String("NULL")) {
