@@ -26,7 +26,7 @@ public:
     void initializePage() override;
 
 private:
-    BlueWizard *m_wizard;
+    BlueWizard *const m_wizard;
 };
 
 #endif // FAIL_H
